@@ -35,7 +35,7 @@ class SegmentationScore:
         
     def seg_stats(self):
         
-        stats = [matching_dataset(self.ground_truth, self.predictions, thresh = t, show_progress = False) for t in tqdm(taus)]    
+        stats = [matching_dataset(self.ground_truth, self.predictions, thresh = t, show_progress = False) for t in tqdm(self.taus)]    
         fig, (ax1,ax2) = plt.subplots(1,2, figsize=(25,10))
 
         for m in ('precision', 'recall', 'accuracy', 'f1', 'mean_true_score', 'panoptic_quality'):
@@ -100,7 +100,13 @@ thresholdtime: tolerance for veto in time
 """
 class ClassificationScore:
     
-    def __init__(self, predictions, groundtruth, segimage, thresholdscore = 1 -  1.0E-6,  thresholdspace = 10, thresholdtime = 2):
+    def __init__(self, predictions, 
+                 groundtruth, 
+                 segimage, 
+                 thresholdscore = 1 -  1.0E-6,  
+                 thresholdspace = 20, 
+                 thresholdtime = 4, 
+                 ignorez= False):
 
          #A list of all the prediction csv files, path object
          self.predictions = list(Path(predictions).glob('*.csv')) 
@@ -111,6 +117,7 @@ class ClassificationScore:
          self.thresholdscore = thresholdscore
          self.thresholdspace = thresholdspace 
          self.thresholdtime = thresholdtime
+         self.ignorez = ignorez
          self.location_pred = []
          self.location_gt = []
 
@@ -130,7 +137,8 @@ class ClassificationScore:
 
     def model_scorer(self):
 
-         self._make_trees()
+         if self.segimage is not None:  
+            self._make_trees()
          Name = []
          TP = []
          FP = []
@@ -144,11 +152,13 @@ class ClassificationScore:
          for index, row in dataset_gt.iterrows():
               T_gt = int(row[0])
               current_point = (row[1], row[2], row[3])
-              tree, indices = self.dicttree[int(T_gt)]
-              distance, nearest_location = tree.query(current_point)
-              nearest_location = (int(indices[nearest_location][0]), int(indices[nearest_location][1]), int(indices[nearest_location][2]))
-              self.location_gt.append([T_gt, nearest_location[0], nearest_location[1], nearest_location[2]])
-        
+              if self.segimage is not None:                
+                tree, indices = self.dicttree[int(T_gt)]
+                distance, nearest_location = tree.query(current_point)
+                nearest_location = (int(indices[nearest_location][0]), int(indices[nearest_location][1]), int(indices[nearest_location][2]))
+                self.location_gt.append([T_gt, nearest_location[0], nearest_location[1], nearest_location[2]])
+              else:
+                self.location_gt.append([int(row[0]),int(row[1]),int(row[2]),int(row[3])])  
          
 
          for csv_pred in self.predictions:
@@ -194,7 +204,7 @@ class ClassificationScore:
                 
                 return_index = self.location_pred[i]
                 closestpoint = tree.query(return_index)
-                spacedistance, timedistance = _TimedDistance(return_index, self.location_gt[closestpoint[1]])
+                spacedistance, timedistance = _TimedDistance(return_index, self.location_gt[closestpoint[1]], self.ignorez)
                     
                 if spacedistance < self.thresholdspace and timedistance < self.thresholdtime:
                         tp  = tp + 1
@@ -223,11 +233,11 @@ class ClassificationScore:
                         return fn
                     
                                 
-def _EuclidMetric(x,y):
+def _EuclidMetric(x: float,y: float):
     
     return (x - y) * (x - y) 
 
-def _MannhatanMetric(x,y):
+def _MannhatanMetric(x: float,y: float):
     
     return np.abs(x - y)
 
@@ -239,13 +249,17 @@ def _ManhattanSum(func):
     
     return float(np.sum(func))
 
-def _general_dist_func(metric):
+def _general_dist_func(metric, ignorez: bool):
      
-     return lambda x,y : [metric(x[i], y[i]) for i in range(1,len(x))]
+     if ignorez:
+         start_dim = 2
+     else:
+         start_dim = 1    
+     return lambda x,y : [metric(x[i], y[i]) for i in range(start_dim,len(x))]
  
-def _TimedDistance(pointA, pointB):
+def _TimedDistance(pointA: tuple, pointB: tuple, ignorez: bool):
 
-     dist_func = _general_dist_func(_EuclidMetric)
+     dist_func = _general_dist_func(_EuclidMetric, ignorez)
      
      spacedistance = _EuclidSum(dist_func(pointA, pointB))
      
